Crate pukram2html

A Rust library for converting Pukram-formatted text to HTML.

Pukram is a lightweight markup language inspired by Markdown, designed for easy formatting of text content. This library is primarily targeted at developers building web servers who need to convert Pukram-formatted text into HTML for displaying on websites. It can also be used to convert Pukram files to HTML, which can then be further converted to PDF using other tools.

Structs

FeatureList
A list to set which features are allowed. By default, all features are allowed.
Settings
Configuration settings for the conversion process.
TextInfo
Struct to hold information about the converted text.

Functions

convert
Convert Pukram to HTML.
convert_extended
Convert Pukram to HTML with extended settings.
convert_subheader
Convert Pukram to HTML with subheaders.